Installation — Lagranto 0.1 documentation

# Installation

## Using pip

Ideally install it in a virtual environment. See for example virtualenvwrapper.

    pip install git+https://git.iac.ethz.ch/npiaget/DyPy.git --process-dependency-links

Then you can install the dependencies for testing or the documentations as follow:

    pip install DyPy[testing]
    pip install DyPy[docs]

To build the documentation do the following:

    cd /path/to/dypy/location
    cd docs
    make html

To test the package do the following:

    cd /path/to/dpyp/location
    pytest